.. :changelog:

History
-------

0.2.0 (2014-11-05)
++++++++++++++++++
* Add pagination in TagListView and CategoryDetailView.
* Improve admin options.


0.1.0 (2014-08-05)
++++++++++++++++++

* First release on PyPI.
